@@ -2,7 +2,10 @@ package Dist::Zilla::PluginBundle::Author::GSG;
 
 # ABSTRACT: Grant Street Group CPAN dists
 use version;
-our $VERSION = 'v0.1.0'; # VERSION
+our $VERSION = 'v0.1.1'; # VERSION
+
+use Carp;
+use Git::Wrapper;
 
 use Moose;
 with qw(
@@ -13,6 +16,11 @@ use namespace::autoclean;
 sub mvp_multivalue_args { qw(
     exclude_filename
     exclude_match
+    test_compile_skip
+    test_compile_file
+    test_compile_module_finder
+    test_compile_script_finder
+    test_compile_switch
 ) }
 
 sub configure {
@@ -63,12 +71,10 @@ sub configure {
             config_plugin      => [ '@Default', 'Contributors' ]
         } ],
 
-        [ 'ChangelogFromGit' => {
-            tag_regexp => '\b(v\d+\.\d+\.\d+(?:\.\d+)*)\b',
-            exclude_message => [ q/(?x: ^Merge \s+ (?:
-                pull \s+ request
-              | (?:remote-tracking\s+)? branch # gitc
-            ) \b )/ ],
+        [ 'ChangelogFromGit::CPAN::Changes' => {
+            file_name    => 'CHANGES',
+            tag_regexp   => '\b(v\d+\.\d+\.\d+(?:\.\d+)*)\b',
+            copy_to_root => 0,
         } ],
 
         [ 'Git::NextVersion' => {
@@ -89,7 +95,23 @@ sub configure {
         'GitHub::Meta',
         'Author::GSG::GitHub::UploadRelease',
 
-        'Test::Compile',
+        [ 'Test::Compile' => $self->config_slice( {
+            map {; "test_compile_$_" => $_ } qw<
+                filename
+                phase
+                skip
+                file
+                fake_home
+                needs_display
+                fail_on_warning
+                bail_out_on_fail
+                module_finder
+                script_finder
+                xt_mode
+                switch
+            >
+        } ) ],
+
         'Test::ReportPrereqs',
     );
 
@@ -99,8 +121,73 @@ sub configure {
 
     push @{ $gather_dir->[2]->{exclude_filename} },
         qw< README.md LICENSE.txt >;
+
+    # By default we want to set the github remote,
+    # but "subclasses" may not want that, so make them
+    # calculate the github_remote themselves.
+    $self->payload->{find_github_remote} //=
+        $self->name eq '@Author::GSG';
+
+    # Look for the GitHub remote, or fail, if we are supposed to.
+    if ( $self->payload->{find_github_remote} ) {
+        $self->payload->{github_remote} //= $self->_find_github_remote
+            // croak "Unable to find git remote for GitHub";
+    }
+
+    $self->_set_github_remote( $self->payload->{github_remote} )
+        if defined $self->payload->{github_remote}
+        and length $self->payload->{github_remote};
 }
 
+
+sub _set_github_remote {
+    my ( $self, $remote ) = @_;
+
+    my @git;
+    my @github;
+
+    foreach my $plugin ( @{ $self->plugins } ) {
+        if ( $plugin->[1] =~ /GitHub/ ) {
+            push @github, $plugin;
+        }
+        elsif ( $plugin->[1] =~ /Git/ ) {
+            push @git, $plugin;
+        }
+    }
+
+    # All our git/github plugins configure this way, so good enough?
+    $_->[2]->{push_to} = [$remote] for @git;
+    $_->[2]->{remote}  = $remote   for @github;
+
+    return $remote;
+}
+
+sub _find_github_remote {
+    my ($self) = @_;
+
+    # If it's a git issue finding the remote,
+    # the user can figure it out.
+    my @remotes = do { local $@; eval { local $SIG{__DIE__};
+        Git::Wrapper->new('.')->remote('-v') } };
+
+    my $remote;
+
+    for (@remotes) {
+        my ( $name, $url, $direction )
+            = /^ (\P{PosixCntrl}+) \s+ (.*) \s+ \( ([^)]+) \) $/x;
+
+        next unless ( $direction || '' ) eq 'push';
+
+        if ( $url =~ m{(?: :// | \@ ) (?: [\w\-\.]+\. )? github\.com\/ }ix ) {
+            croak "Multiple git remotes found for GitHub" if defined $remote;
+            $remote = $name;
+        }
+    }
+
+    return $remote;
+}
+
+
 __PACKAGE__->meta->make_immutable;
 
 package # hide from the CPAN
@@ -157,7 +244,7 @@ Dist::Zilla::PluginBundle::Author::GSG - Grant Street Group CPAN dists
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -185,6 +272,14 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     ; in order to support "version ranges".
     eumm_version = 7.1101
 
+    ; We try to guess which remote to use to talk to GitHub
+    ; but you can hardcode a value if necessary
+    github_remote = # detected from git if find_github_remote is set
+
+    ; Enabled by default if the PluginBundle name is Author::GSG
+    ; This means Filters do not automatically get it set
+    find_github_remote = 1
+
     ; The defaults for author and license come from
     [Author::GSG]
 
@@ -229,6 +324,19 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     [GitHub::UploadRelease] # plus magic to work without releasing elsewhere
 
     [Test::Compile]
+    ; test_compile_filename
+    ; test_compile_phase
+    ; test_compile_skip
+    ; test_compile_file
+    ; test_compile_fake_home
+    ; test_compile_needs_display
+    ; test_compile_fail_on_warning
+    ; test_compile_bail_out_on_fail
+    ; test_compile_module_finder
+    ; test_compile_script_finder
+    ; test_compile_xt_mode
+    ; test_compile_switch
+
     [Test::ReportPrereqs]
 
 =head1 DESCRIPTION
@@ -260,6 +368,24 @@ as well as incrementing a more strict C<semver>.
 
 =over
 
+=item github_remote / find_github_remote
+
+Looks in the C<git remote> list for a C<push> remote that matches
+C<github.com> (case insensitively) and if we find one,
+we pass it to the Git and GitHub Plugins we use.
+
+If no remotes or multiple remotes are found, throws an exception
+indicating that you need to add the GitHub remote as described in
+L</Cutting a release>.
+
+Trying to find a remote, and failing if it isn't found,
+is only enabled if you set C<find_github_remote> to a truthy value.
+However, C<find_github_remote> defaults to truthy if the section
+name for the PluginBundle is the default, C<@Author::GSG>.
+
+You can disable this, and fall back to each Plugin's default,
+by setting C<github_remote> to an empty string.
+
 =item meta_provides
 
     [@Author::GSG]
@@ -294,6 +420,15 @@ Automatically appends C<README.md> and C<LICENSE.txt> to the list.
 
 Passed to L<Dist::Zilla::Plugin::Git::GatherDir/exclude_match>.
 
+=item test_compile_*
+
+    [@Author::GSG]
+    test_compile_skip    = ^My::NonCompiling::Module$
+    test_compile_xt_mode = 1
+
+All options for L<Dist::Zilla::Plugin::Test::Compile> should be supported
+with the C<test_compile_> prefix.
+
 =back
 
 =head1 Setting up a new dist
